unit Led;

{$mode Delphi}{$H+}

interface

uses
  Classes, SysUtils, LResources, Forms, Messages, LMessages, Controls,
  Graphics, Dialogs;

type
  TState = (ldOff, ldOn);
  TLedColor = (lcRed, lcGreen, lcYellow, lcBlue);

  { TLed }

  TLed = class(TGraphicControl)
  private
     FPixmap: TPixmap;
     FState: TState;
     FLedColor: TLedColor;
     FMouseLeave: TNotifyEvent;
     procedure SetState(Value: TState);
     procedure SetColor(Value: TLedColor);
     procedure CMMouseLeave(var Message: TMessage); message CM_MOUSELEAVE;
    { Private declarations }
  protected
    { Protected declarations }
  public
   constructor create(TheOwner: TComponent); override;
   destructor Destroy; override;
   procedure paint; override;

    { Public declarations }
  published
    property State: TState read FState write SetState;
    property Color: TLedColor read FLedColor write SetColor;
    property Action;
    property Anchors;
    property Visible;
    property Cursor;
    property OnClick;
    property OnDblClick;
    property OnMouseDown;
    property OnMouseMove;
    property OnMouseUp;
    property OnMouseLeave: TNotifyEvent read FMouseLeave write FMouseLeave;
    property OnPaint;
    property OnResize;
    property OnChangeBounds;
    property ShowHint;
    property ParentShowHint;
    property PopupMenu;
    property Enabled;
    { Published declarations }
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('AthmsPack',[TLed]);
end;

{ TLed }

procedure TLed.SetState(Value: TState);
begin
  FState:= Value;
   if FState = ldOn then
     case FLedColor of
      lcRed: FPixmap.LoadFromLazarusResource('RedOnLed');
      lcGreen: FPixmap.LoadFromLazarusResource('GrnOnLed');
      lcYellow: FPixmap.LoadFromLazarusResource('YlwOnLed');
      lcBlue: FPixmap.LoadFromLazarusResource('BluOnLed');
     end;
   if FState = ldOff then
     case FLedColor of
      lcRed: FPixmap.LoadFromLazarusResource('RedOffLed');
      lcGreen: FPixmap.LoadFromLazarusResource('GrnOffLed');
      lcYellow: FPixmap.LoadFromLazarusResource('YlwOffLed');
      lcBlue: FPixmap.LoadFromLazarusResource('BluOffLed');
     end;
     Invalidate;
end;

procedure TLed.SetColor(Value: TLedColor);
begin
    FLedColor:= Value;
       if FState = ldOn then
     case FLedColor of
      lcRed: FPixmap.LoadFromLazarusResource('RedOnLed');
      lcGreen: FPixmap.LoadFromLazarusResource('GrnOnLed');
      lcYellow: FPixmap.LoadFromLazarusResource('YlwOnLed');
      lcBlue: FPixmap.LoadFromLazarusResource('BluOnLed');
     end;
   if FState = ldOff then
     case FLedColor of
      lcRed: FPixmap.LoadFromLazarusResource('RedOffLed');
      lcGreen: FPixmap.LoadFromLazarusResource('GrnOffLed');
      lcYellow: FPixmap.LoadFromLazarusResource('YlwOffLed');
      lcBlue: FPixmap.LoadFromLazarusResource('BluOffLed');
     end;
     Invalidate;
end;

procedure TLed.CMMouseLeave(var Message: TMessage);
begin
      Invalidate;
      if Assigned(FMouseLeave) then FMouseLeave(self);
end;

constructor TLed.create(TheOwner: TComponent);
begin
  inherited create(TheOwner);
  Height:= 16;
  Width:= 16;
  FPixmap:= TPixmap.Create;
  FPixmap.Transparent:= True;
  FPixmap.LoadFromLazarusResource('RedOffLed');
end;

destructor TLed.Destroy;
begin
  FPixmap.Free;
  inherited Destroy;
end;

procedure TLed.paint;
begin
 With Canvas do
   begin
     Canvas.Ellipse(0,0,16,16);
     Draw(0,0, FPixmap);
   end;
end;

initialization
  {$I led.lrs}
  {$I TLed.lrs}
end.
